#
# spec file for package rabbitmq-server
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%bcond_without split_plugins

# We want to install into /usr/lib, even on 64-bit platforms
%define _rabbit_libdir %{_exec_prefix}/lib/rabbitmq
%define _rabbit_erllibdir %{_rabbit_libdir}/lib/rabbitmq_server-%{version}

%if %{undefined _initddir}
%define _initddir %{_sysconfdir}/init.d
%endif

%define _make_args DESTDIR="%{buildroot}" PREFIX="%{_exec_prefix}" RMQ_ROOTDIR=%{_rabbit_libdir} RMQ_ERLAPP_DIR=%{_rabbit_erllibdir} MANDIR="%{_mandir}" DOC_INSTALL_DIR=%{buildroot}/%{_docdir} VERSION=%{version} V=1

%define _plugins_state_dir %{_localstatedir}/lib/rabbitmq/plugins
%define _rabbitmqctl_autocomplete scripts/bash_autocomplete.sh
%define _rabbitmq_user rabbitmq
%define _rabbitmq_group rabbitmq

%define _rname rabbitmq-server

Name:           rabbitmq-server313
Version:        3.13.1
Release:        150600.13.5.3
Summary:        A message broker supporting AMQP, STOMP and MQTT
License:        MPL-2.0
Group:          System/Daemons
URL:            https://www.rabbitmq.com/
Source:         https://github.com/rabbitmq/rabbitmq-server/releases/download/v%{version}/rabbitmq-server-%{version}.tar.xz
Source1:        https://github.com/rabbitmq/rabbitmq-server/releases/download/v%{version}/rabbitmq-server-%{version}.tar.xz.asc
Source2:        https://github.com/rabbitmq/signing-keys/releases/download/2.0/rabbitmq-release-signing-key.asc#/%{_rname}.keyring
Source3:        https://raw.githubusercontent.com/rabbitmq/rabbitmq-packaging/v%{version}/RPMS/Fedora/rabbitmq-server.logrotate
Source4:        rabbitmq-env.conf
Source6:        rabbitmq-server.service
Source7:        https://raw.githubusercontent.com/rabbitmq/rabbitmq-packaging/v%{version}/RPMS/Fedora/rabbitmq-server.tmpfiles
Source8:        README.SUSE
BuildRequires:  elixir >= 1.13.4
# https://www.rabbitmq.com/which-erlang.html
BuildRequires:  erlang >= 25.0
BuildRequires:  erlang-src  >= 25.0
BuildRequires:  hostname
BuildRequires:  fdupes
# BuildRequires:  libxslt
BuildRequires:  python3
BuildRequires:  rsync
BuildRequires:  unzip
BuildRequires:  xmlto
BuildRequires:  xz
BuildRequires:  zip
Requires:       erlang >= 25.0
Requires:       erlang-epmd  >= 25.0
Requires:       logrotate
Provides:       AMQP-server
Requires(pre):  shadow
Requires(pre):  %fillup_prereq
Requires:       rabbitmq-server-plugins
BuildRequires:  pkgconfig(systemd)
Provides:       group(%{_rabbitmq_group})
Provides:       user(%{_rabbitmq_user})
Provides:       rabbitmq-server
Conflicts:      rabbitmq-server
%{?systemd_ordering}
# Do not use noarch since the Erlang packaging does not really allow that
#BuildArch:      noarch

%description
RabbitMQ is an implementation of an AMQP broker. AMQP is an emerging
standard for messaging.

%package plugins
Summary:        Plugins for the RabbitMQ server
Group:          System/Daemons
Requires:       rabbitmq-server = %{version}
Provides:       %{_rname}-plugins
Conflicts:      %{_rname}-plugins

%description plugins
RabbitMQ is an implementation of an AMQP broker. AMQP is an emerging
standard for messaging.

This package includes some plugins for the RabbitMQ server.

%package -n erlang-rabbitmq-client313
Summary:        RabbitMQ AMQP language bindings for Erlang
Group:          Development/Libraries/Other
Requires:       erlang
Provides:       erlang-amqp_client = %{version}
Provides:       erlang-gen_server2 = %{version}
Provides:       erlang-rabbit_common = %{version}
Conflicts:      erlang-rabbitmq-client

%description -n erlang-rabbitmq-client313
RabbitMQ is an implementation of an AMQP broker. AMQP is an emerging
standard for messaging.

This package includes the RabbitMQ AMQP language bindings for Erlang.

%package bash-completion
Summary:        Bash completion for %{_rname}
Group:          System/Shells
Requires:       %{_rname} = %{version}
Requires:       bash-completion
Supplements:    (%{_rname} and bash-completion)
Conflicts:      %{_rname}-bash-completion
BuildArch:      noarch

%description bash-completion
Optional dependency offering bash completion for %{_rname}.

%package zsh-completion
Summary:        Zsh completion for %{_rname}
Group:          System/Shells
BuildRequires:  zsh
Requires:       %{_rname} = %{version}
Requires:       zsh
Supplements:    (%{_rname} and zsh)
Conflicts:      %{_rname}-zsh-completion
BuildArch:      noarch

%description zsh-completion
Optional dependency offering zsh completion for %{_rname}.

%prep
%autosetup -p1 -n %{_rname}-%{version}
cp %{SOURCE8} .

%build
# Make elixir happy with Unicode
export LANG=en_US.UTF-8
export PYTHON=%{_bindir}/python3
make all %{_make_args} %{?_smp_mflags}

%install
# Make elixir happy with Unicode
export LANG=en_US.UTF-8
export PYTHON=%{_bindir}/python3
make install install-bin install-man %{_make_args}

mkdir -p %{buildroot}%{_sbindir}
install -p -D -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/%{_rname}.service
ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{_rname}
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{_rname}.conf
# Use /run instead of deprecated /var/run in tmpfiles.conf  (bsc#1185075)
sed -i 's/\/var//' %{buildroot}%{_prefix}/lib/tmpfiles.d/%{_rname}.conf

# Install wrapper scripts
sed \
  -e 's|@RABBITMQ_USER@|%{_rabbitmq_user}|' -e 's|@RABBITMQ_GROUP@|%{_rabbitmq_group}|' \
  < scripts/rabbitmq-script-wrapper \
  > %{buildroot}%{_sbindir}/rabbitmqctl
chmod 0755 %{buildroot}%{_sbindir}/rabbitmqctl
for script in rabbitmq-server rabbitmq-plugins rabbitmq-diagnostics rabbitmq-queues rabbitmq-upgrade rabbitmq-streams; do \
  cp -a %{buildroot}%{_sbindir}/rabbitmqctl %{buildroot}%{_sbindir}/$script
done

# install config files
install -p -D -m 0644 deps/rabbit/docs/rabbitmq.conf.example %{buildroot}/%{_sysconfdir}/rabbitmq/rabbitmq.conf
install -p -D -m 0644 deps/rabbit/docs/advanced.config.example %{buildroot}/%{_sysconfdir}/rabbitmq/advanced.config.example
install -p -D -m 0644 deps/rabbit/docs/rabbitmq.conf.example %{buildroot}/%{_sysconfdir}/rabbitmq/rabbitmq.config.example
install -p -D -m 0644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/rabbitmq/rabbitmq-env.conf

# Copy all necessary lib files etc.
install -p -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/rabbitmq-server

# Install autocomplete scripts
for script in rabbitmqctl rabbitmq-plugins rabbitmq-diagnostics; do
  install -p -D -m 0644 %{_rabbitmqctl_autocomplete} %{buildroot}%{_datadir}/bash-completion/completions/$script
done
install -p -D -m 0644 scripts/zsh_autocomplete.sh %{buildroot}%{_datadir}/zsh/site-functions/_enable_rabbitmqctl_completion

# Install Erlang client
mkdir -p %{buildroot}%{_libdir}/erlang/lib
for i in amqp_client rabbit_common ; do
  cp -r %{buildroot}%{_rabbit_erllibdir}/plugins/$i* -d %{buildroot}%{_libdir}/erlang/lib/
done

# Create other necessary directories for RabbitMQ server
mkdir -p %{buildroot}%{_sysconfdir}/rabbitmq
mkdir -p %{buildroot}%{_localstatedir}/lib/rabbitmq/mnesia
mkdir -p %{buildroot}%{_localstatedir}/log/rabbitmq

# Create hardlinks for duplicate files
%fdupes %{buildroot}/%{_datadir}
%fdupes %{buildroot}/%{_libdir}
%fdupes %{buildroot}/%{_sbindir}

%pre
getent group %{_rabbitmq_group} >/dev/null || groupadd -r %{_rabbitmq_group}
getent passwd %{_rabbitmq_user} >/dev/null || useradd -r -g %{_rabbitmq_group} \
  -d %{_localstatedir}/lib/rabbitmq \
  -s /sbin/nologin \
  -c "user for RabbitMQ messaging server" %{_rabbitmq_user}
%service_add_pre %{_rname}.service

%post
%service_add_post %{_rname}.service
systemd-tmpfiles --create --clean /usr/lib/tmpfiles.d/rabbitmq-server.conf

%preun
# Clean out plugin activation state, both on uninstall and upgrade
rm -rf %{_plugins_state_dir}
for ext in rel script boot ; do
    rm -f %{_rabbit_erllibdir}/ebin/rabbit.$ext
done

%service_del_preun %{_rname}.service

%postun
%service_del_postun %{name}.service

%files
%config(noreplace) %{_sysconfdir}/logrotate.d/rabbitmq-server
%config(noreplace) %{_sysconfdir}/rabbitmq/
%{_rabbit_libdir}
%if %{with split_plugins}
%exclude %{_rabbit_erllibdir}/plugins/rabbitmq_*
%endif
#
%{_unitdir}/%{_rname}.service
/usr/lib/tmpfiles.d/rabbitmq-server.conf
#
%attr(0755, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq/mnesia
%attr(0755, rabbitmq, rabbitmq) %dir %{_localstatedir}/log/rabbitmq
#
%{_sbindir}/rabbitmq-plugins
%{_sbindir}/rabbitmq-server
%{_sbindir}/rabbitmqctl
%{_sbindir}/rabbitmq-queues
%{_sbindir}/rabbitmq-upgrade
%{_sbindir}/rcrabbitmq-server
%{_sbindir}/rabbitmq-diagnostics
%{_sbindir}/rabbitmq-streams

#
%license LICENSE*
%doc README* CODE_OF_CONDUCT.md CONTRIBUTING.md deps/rabbit/docs/set_rabbitmq_policy.sh.example
%{_mandir}/man5/rabbitmq-env.conf.5%{?ext_man}
%{_mandir}/man8/rabbitmq*.8%{?ext_man}
# E: script-without-shebang
%exclude %{_rabbit_libdir}/autocomplete/bash_autocomplete.sh
%exclude %{_rabbit_libdir}/autocomplete/zsh_autocomplete.sh

%if %{with split_plugins}
%files plugins
%{_rabbit_erllibdir}/plugins/rabbitmq_*
%endif

%files -n erlang-rabbitmq-client313
%{_libdir}/erlang/lib/amqp_client*/
%{_libdir}/erlang/lib/rabbit_common*/

%files bash-completion
%{_datadir}/bash-completion/completions/rabbitmq*

%files zsh-completion
%{_datadir}/zsh/site-functions/_enable_rabbitmqctl_completion

%changelog
* Fri May 31 2024 simonf.lees@suse.com
- Create a versioned package for SLES
-  The following bugfixes and CVE's were fixed upstream
  (bsc#1186203,CVE-2021-22116), (bsc#1187818, CVE-2021-32718),
  (bsc#1187819, CVE-2021-32719) (bsc#1199431),
  (bsc#1205267), (bsc#1216582, CVE-2022-31008)
* Tue Apr 16 2024 sflees@suse.de
- Update to 3.13.1
  * Highlights
    Khepri now can be used as an alternative schema data store in RabbitMQ, replacing Mnesia
    MQTTv5 support
    Support for consumer-side stream filtering
    A new common message container format used internally, based on the AMQP 1.0 message format
    Improved classic non-mirrored queue performance with message sizes larger than
    4 KiB (or a different customized CQ index embedding threshold)
    Classic queues storage implementation version 2 (CQv2) is now highly recommended for all new deployments.
    CQv2 meaningfully improves performance of non-mirrored classic queues for most workloads
  * Fixes bsc#1222591
* Tue Feb  6 2024 dimstar@opensuse.org
- Provide user/group for RPM 4.19 (boo#1219532).
* Sat Jan  6 2024 dmueller@suse.com
- update to 3.12.11:
  * Quorum queue declared when one of cluster nodes was down
    could trigger connection exceptions.
  * Avoids a rare exception that could stop TCP socket writes on
    a client connection.
  * `queue_deleted` and `queue_created` internal events now
    include queue type as a module name, and not an inconsistent
    (with the other queue and stream types) value `classic`.
  * Definition files that are virtual host-specific cannot be
    imported on boot. Such files will now be detected early and
    the import process will terminate after logging a more
    informative message.
  * Several AMQP 1.0 application properties are now more
    correctly converted to AMQP 0-9-1 headers by
    cross-protocol Shovels.
  * The priority property now populates an AMQP 1.0 header with
    the same name, per AMQP 1.0 spec.
  * Metric label values now escape certain non-ASCII characters.
  * Avoids an exception when an MQTT client that used a QoS 0
    subscription reconnects and its original connection node
    is down.
  * Avoids an exception when an MQTT client connection was force-
    closed via the HTTP API.
  * Certain CLI commands could not be run in a shell script loop,
    unless the script explicitly redirected standard input.
  * `rabbitmq-diagnostics cluster_status` now responds much
    quicker when a cluster node has gone down, were shut down,
    or otherwise has become unreachable by the rest of the cluster.
  * Reverted a change to `DELETE /api/queues/{vhost}/{name}` that
    allowed removal of exclusive queues and introduced
    unexpected side effects.
  * `DELETE /api/policies/{vhost}/{policy}` returned a 500
    response instead of a 404 one when target virtual host did
    not exist.
  * Avoid log noise when an HTTP API request is issued against a
    booting or very freshly booted node.
  * HTTP API endpoints that involves contacting multiple nodes
    now respond much quicker when a cluster node
    has gone down, were shut down, or otherwise has become
    unreachable by the rest of the cluster
  * Definition exported for just one virtual host cannot be
    imported at node boot time.
  * Now such files are detected early with a clear log message
    and immediate node boot process termination.
  * To obtain source code of the entire distribution, please
    download the archive named `rabbitmq-server-3.12.11.tar.xz`
    instead of the source tarball produced by GitHub.
* Sun Dec 17 2023 dmueller@suse.com
- update to 3.12.10:
  * Avoids two Shovels being started after an upgrade from 3.12.6
    or older versions.
  * When a topic permission was deleted, an internal event of type
    permission.deleted was emitted in some cases, instead of
    topic.permission.deleted.
  * Shovels on 3.12.8 nodes failed during a rolling cluster upgrade
    due to internal identifier format changes.
  * Avoids an unnecessary warning in the logs.
  * avoids a potential exception in the autoheal partition handler.
  * raft.segment_max_entries is now validated to prevent the value
    from overflowing its 16-bit segment file field. Maximum
    supported value is now 65535.
* Sun Oct 29 2023 dmueller@suse.com
-  update to 3.12.7:
  * Stream replication connections configured to use exclusively
    TLSv1.3 failed.
  * On startup, stream replicas will handle one more potential
    case of segment file corruption after an unclean shutdown.
  * `default_policies.*.queue_pattern` definition in
    `rabbitmq.conf` was incorrectly parsed.
  * Avoid log noise when inter-node connections frequently fail
    and recover.
  * Optimized stream index scans. Longer scans could result in
    some replicas stopping with a timeout.
  * Classic queue storage version is now a supported key for
    operator policies.
  * Queue length limit overflow behavior now can be configured
    via operator policies.
  * Several `list_stream_*` commands (available via both
    `rabbitmq-diagnostics` and `rabbitmq-streams`) commands now
    can display replica node in addition to other fields.
  * `rabbitmqctl add_user` now can accept a pre-generated salted
    password instead of a plain text password, both as a
    positional argument and via standard input:
  * Message consumption with the "Nack message, requeue: true"
    option did not actually requeue deliveries.
  * HTTP API request body size is now limited to 10 MiB by
    default.
  * Two endpoints, one that accepts messages for publishing
    (note: publishing over the HTTP API is greatly discouraged)
  * and another for definition import,
  * will now reject larger transfers with a `400 Bad Request`
    response.
  * `DELETE /api/queues/{vhost}/{name}` now can delete exclusive
    queues.
  * Key supported by operator policies are now grouped by queue
    type in the UI.
  * Improved data safety for confirms in environments where the
    plugin uses classic queues.
  * Avoid an exception when a not fully established MQTT-over-
    WebSockets connection terminated.
  * Recovery of bindings of durable queues bound to a transient
    JMS topic exchange failed.
  * Recovery of bindings of durable queues bound to a transient
    `x-modulo-hash` exchange failed.
  * Recovery of bindings of durable queues bound to a transient
    recent history exchange failed.
  * `osiris` has been upgraded to `1.6.9`
  * Queue recovery on node restart in certain conditions could
    run into an exception
  * `file_handle_cache` operations are now safer when handling
    non-existent keys.
  * Fixed a potential resource leak in at-least-once dead
    lettering from quorum queues.
  * AMQP 1.0 clients that try to publish in a way that results in
    the message not being routed anywhere are now notified with
    a more sensible settlement status.
  * Prometheus scraping API endpoints now support optional
    authentication.
  * The plugin now filters out values that are `undefined` or
    `NaN`, simply excluding them from the API endpoint response.
    Previously, if a metric was not computed for any reason (e.g.
    free disk space monitor was disabled on the node),
    its value could end up being rendered as `undefined` or `NaN`,
    two values that Prometheus scrapers cannot handle (for
  * The plugin will now enforce maximum STOMP frame size. Frames
    larger than that size will be rejected. The default maximum
    size is 4 MiB. It can be increased or decreased:
  * ``` ini
  * # increase maximum supported STOMP frame size to 10 MiB
  * stomp.max_frame_size = 10485760
  * ```
  * To reduce it from the default 4 MiB to 2 MiB:
  * ``` ini
  * # 2 MiB
  * stomp.max_frame_size = 2097152
  * ```
  * Shovel will gracefully stop when its destination (target)
    does not exist.
  * Such shovels will then be periodically restarted to retry.
  * It is now possible to opt in to deactivate file handle cache
    use in the plugin:
  * ``` ini
  * web_mqtt.use_file_handle_cache = false
  * ```
  * It is now possible to opt in to deactivate file handle cache
    use in the plugin:
  * ``` ini
  * web_stomp.use_file_handle_cache = false
  * ```
  * `ra` was upgraded to `2.6.3`
  * Declaration of a classic queue could run into an exception.
  * Classic queues v1 (CQv1) that had a backlog of messages
    stored by 3.9 and earlier versions could run into an exception
    during queue index recovery after an upgrade to 3.10.x or any
    later series.
  * Nodes that had a large number of quorum queues could observe
    accumulation of Erlang processes under significant load.
  * Feature flag discovery on a newly added node could discover
    an incomplete inventory of feature flags.
  * Feature flag discovery operations will now be retried
    multiple times in case of network failures.
  * Nodes in clusters that had quorum queues and non-mirrored
    classic queues on stopped (or failed) nodes could run into an
    exception.
  * The same exception could affect `rabbitmqctl list_queues`.
  * Proxy Protocol v2 LOCAL packets were not supported.
  * When a quorum queue does not find its local replica data
    files on boot, it will now log a warning.
  * An attempt to clear limits of a non-existent virtual host
    failed with a 500 status code.
  * The "Queues" tab in the UI was renamed to "Queue and Streams"
    to better reflect its contents.
  * New HTTP API endpoints for quorum queue replica management,
    equivalent to the `rabbitmq-queues` commands that manage replicas.
  * ```
  * POST /api/queues/quorum/{vhost}/{name}/replicas/add
  * DELETE /api/queues/quorum/{vhost}/{name}/replicas/remove
  * POST /api/queues/quorum/replicas/on/{node}/grow
  * DELETE /api/queues/quorum/replicas/on/{node}/shrink
  * ```
  * Stream client connections that authenticated using x.509
    certificates failed.
  * Only set OAuth 2 client's CA certificate file setting when it
    is defined.
  * The plugin will now accept JWT tokens without a `scope`. Such
    tokens would only be useful when the plugin is used exclusively
    for authentication and not authorization.
  * `oauth2` is now an accepted alias for the OAuth 2
    authentication and authorization backend:
  * ```
  * auth_backends.1 = oauth2
  * ```
  * Previously the only option for OAuth 2 was using a full
    module name, `rabbit_auth_backend_oauth2`.
  * STOMP plugin log entries had an extra line feed character.
  * `ra` was upgraded to `2.6.2`
* Tue Jul 18 2023 matwey.kornilov@gmail.com
- Improve erlang-rabbitmq-client Provides:
  The package provides two erlang applications: amqp_client and rabbit_common
  which are expected to be Required as erlang-%%{appname}
* Mon Jun  5 2023 qydwhotmail@gmail.com
- Update to 3.12.0
  * Optimizations for both quorum and classic queues: improved throughput,
    lower throughput variability, lower latency, lower memory footprint
  * More mature and efficient implementation of (non-mirrored) classic
    queues v2 (CQv2)
  * Classic queue lazy and non-lazy modes no longer apply: classic
    queues v2 always behave very similarly
  * to the lazy mode in earlier release series: moving data to disk
    aggressively and only keeping a subset of data in memory
  * Significantly reduced MQTT and Web MQTT memory footprint per connection
  * OAuth 2, OIDC, IDP support
  * Even more configurability of the OAuth 2 plugin
- More bugfixes and enhancements:
  https://www.rabbitmq.com/changelog.html
* Wed Nov  9 2022 qydwhotmail@gmail.com
- Update to 3.11.3
  + Core Server
  * Stream unsubscription leaked metric counters.
  * Stream could become unavailable in certain node or network
    failure scenarios.
  * It is now possible to pre-configure virtual host limits for
    groups of virtual hosts.
  * Quorum queue replicas no longer try to contact their unreachable
    peers for metrics.
  + CLI Tools
  * rabbitmq-diagnostics status now handles server responses where
    free disk space is not yet computed.
  * All enabled (explicitly or as a dependency) plugins are scanned.
  * rabbitmq-diagnostics memory_breakdown now returns results much
    faster in environments with a large number of quorum queues.
* Wed Oct 26 2022 dimstar@opensuse.org
- Update to version 3.10.10:
  + Core Server
  * Partially reverts an unsafe inter-node communication
    optimization that could affect classic mirrored queue
    operation ordering.
  * Classic mirrored queue leader replica issued to much credit
    to follower replicas, resulting in an uneven load and
    memory footprint between them.
  * Intra-cluster communication link metric collector could run
    into an exception when peer connection has just been
    re-established, e.g. after a peer node restart.
  + MQTT Plugin
  * When a node was put into maintenance mode, it closed all MQTT
    client connections cluster-wide instead of just local client
    connections.
- For updates between 3.10.5 and 3.10.9, please see
  https://www.rabbitmq.com/changelog.html
* Sat Jun 18 2022 qydwhotmail@gmail.com
- Update to 3.10.5
  * Quorum queue could run into an exception when dead lettering a message
    under certain conditions.
- Changes from 3.10.4
  * Avoid seeding default user in old clusters that still use the deprecated
    management.load_definitions option.
  * Streams could run into an exception or fetch stale stream position
    data in some scenarios.
  * rabbitmqctl set_log_level did not have any effect on logging via
    amq.rabbitmq.log
* Sat May 21 2022 qydwhotmail@gmail.com
- Update to 3.10.2
  * Default log level used a four-character severity abbreviation
    instead of more common longer format, for example, warn instead
    of warning.
  * Fix CLI tools failed to run on Erlang 25
* Wed May 11 2022 andreas.stieger@gmx.de
- add upstream signing key and verify source signature
* Sun May  8 2022 qydwhotmail@gmail.com
- Update to 3.10.0
  * See https://github.com/rabbitmq/rabbitmq-server/blob/v3.10.x/release-notes/3.10.0.md
    for the full changelog.
  * Potentially breaking changes
  - Messages delivered by a quorum queue and negatively acknowledged
    with a requeue will be added to the back of the queue until the
    queue has redelivery limit set. With a redelivery limit, requeueing
    will use the original position of the message if possible.
  - idle_since field now uses RFC 3339 format.
* Fri Mar 25 2022 qydwhotmail@gmail.com
- Update to 3.9.14
  * See https://github.com/rabbitmq/rabbitmq-server/blob/v3.9.x/release-notes/3.9.14.md
    for the full changelog.
  * Build time compatibility with Elixir 1.13 (gh#rabbitmq/rabbitmq-server#4019)
  - Drop Elixir-1.13-OptionParser-no-longer-supports-atom-val.patch
  - Drop Support-Elixir-1.13.patch
  * Adapt to a breaking Erlang 24.3 LDAP client change.
* Sat Feb 19 2022 qydwhotmail@gmail.com
- Add zsh BuildRequires to fix "directories not owned by a package"
  in zsh-completion.
* Wed Jan 19 2022 qydwhotmail@gmail.com
- Update to 3.9.13
  * Core Server Bug Fixes and Enhancements
  - Disk space monitor now correctly parses output on (at least
    some) systems where non-ASCII characters are used in paths.
  - Stream leader election is now deterministic when cluster is
    undergoing a rolling upgrade.
  - Queue and binding definition import can be delayed until a
    moment when at least N nodes (e.g. three) have joined the
    cluster.
- Allow building with Elixir 1.13.x
  * Support-Elixir-1.13.patch
  * Elixir-1.13-OptionParser-no-longer-supports-atom-val.patch
* Thu Jan  6 2022 qydwhotmail@gmail.com
- Update to 3.9.12
  * See https://github.com/rabbitmq/rabbitmq-server/blob/v3.9.x/release-notes/3.9.12.md
    for the full changelog.
  * Core Server Bug Fixes and Enhancements
  - (Fix) Authentication and authorization backend exceptions
    could potentially leak user-provided credentials to node log.
  - Unnamed parameters and policies in definition files will now
    be rejected as invalid.
* Thu Dec  2 2021 qydwhotmail@gmail.com
- Update to 3.9.11
  * Core Server Bug Fixes
  - When a TLS-enabled listener failed to stop, it logged all of
    its settings which could contain sensitive values.
  * Core Server Enhancements
  - Quorum queues now store commands for enqueued messages in a
    more compact format on disk (some derivative data has been dropped).
  - queue.declare-ok response to AMQP 0-9-1 clients operating on
    a stream could return a ready-for-delivery message count
    value that was out of sync with the stream leader replica.
  - Classic queues now deliver more efficiently on channels that
    had global QoS changed during consumer operation.
  * Prometheus Plugin Enhancements
  - New optional metrics provided by the GET /metrics/detailed
    endpoint. These metrics are cluster-wide, and therefore must
    not be aggregated.
  * Management Agent Plugin Enhancements
  - Disabling the plugin will stop metric collection performed
    periodically by queues, streams, connections, et cetera.
- Changes in 3.9.10:
  * Core Server Bug Fixes
  - Make stream coordinator more defensive to rapid declaration
    and deletion cycles.
  * Core Server Enhancements
  - Several inter-node communication listener settings are now
    exposed to rabbitmq.conf:
    + distribution.listener.port_range.min = 25675
    + distribution.listener.port_range.max = 25675
    + distribution.listener.interface = 192.168.0.1
  * OAuth 2 Plugin Bug Fixes
  - Signing keys specified in rabbitmq.conf were not translated
    correctly, resulting in exceptions during permission checks.
- Drop upstreamed patch
  * harden_rabbitmq-server.service.patch: https://github.com/rabbitmq/rabbitmq-server/pull/3770
* Fri Nov 19 2021 qydwhotmail@gmail.com
- Update to 3.9.9:
  * Core Server Bug Fixes
  - Fixed an issue where node monitor could produce a false network
    partition when one of the cluster members was restarted.
  - Message store resiliency improvements.
  - Reduced log noise in certain scenarios where a new queue leader
    is elected.
  - Queue leader rebalancing now logs less.
  * Prometheus Plugin Bug Fixes
  - TLS-enabled Prometheus endpoint listener port was not correctly
    stored internally.
  * Management Plugin Bug Fixes
  - Persistent message count is now displayed correctly on
    individual queue pages.
  - Restore compatibility with IE 11.
  * Consistent Hashing Exchange Plugin Bug Fixes
  - Corrected deletion of duplicate bindings between an exchange
    and a queue.
  * Enhancements
  - Core Server: cluster_formation.target_cluster_size_hint is a
    new configuration setting that can be used to specify expected
    initial cluster size.
  - Prometheus Plugin: Metric rendering efficiency improvements
    (mostly latency).
- Don't install the (now gone) OCF script.
- Refreshed patch:
  * harden_rabbitmq-server.service.patch
* Thu Oct 21 2021 jsegitz@suse.com
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_rabbitmq-server.service.patch
  Modified:
  * rabbitmq-server.service
* Wed Oct 20 2021 qydwhotmail@gmail.com
- Update to 3.9.8:
  * Core Server Bug Fixes
  - When the mandatory flag was used when publishing to classic
    queues, but publisher confirms were not, channels memory
    usage would grow indefinitely.
  - rabbitmq-diagnostics memory_breakdown failed to read memory
    of connection reader, writer and channel processes.
  - In some environments, Stream replicas advertised IP
    addresses that could not be reached by cluster peers.
    RabbitMQ node hostnames are now advertised as well so that
    other peers can resolve them to get an externally visible IP
    address.
  * Prometheus Plugin Enhancements
  - More data is exposed via the GET /metrics/detailed endpoint.
  * Management Plugin Bug Fixes
  - When setting topic permissions, the list of exchanges in the
    UI now honors the currently selected virtual host.
  * AWS Peer Discovery Plugin Enhancements
  - The plugin now logs more details for failed AWS API
    requests.
  * Web STOMP Plugin Enhancements
  - STOMP-over-WebSockets connections now can consume from
    streams.
* Fri Sep 24 2021 qydwhotmail@gmail.com
- Update to 3.9.7:
  + All Components
  * All bytecode is now compiled using the +deterministic
    compiler flag. This should eliminate the capture of some
    irrelevant build environment attributes in produced
    artifacts, improve consistency between builds, and reduce the
    file level diff between release artifacts.
  + Core Server
  * Enhancements
  - Classic queue shutdown now uses a much higher timeout (up
    to 10 minutes instead of 30 seconds).
  - In environments with many queues (especially mirrored
    queues) and many consumers this means that the chance of
    queue indices rebuilding after node restart is now
    substantially lower.
  * Bug Fixes
  - Quorum queues no longer leak memory and disk space when a
    consumer is repeatedly added and cancelled on an empty
    queue.
  + Prometheus Plugin
  * Enhancements
  - More configurability for metrics exposed via the Prometheus
    endpoint.
  + Shovel Plugin
  * Bug Fixes
  - Shovel URIs could be logged with credentials in some
    scenarios.
  + Dependency Upgrades
  * observer_cli has been upgraded from 1.6.2 to 1.7.1
* Fri Sep 17 2021 qydwhotmail@gmail.com
- Update to 3.9.6:
  + Core Server
  * Bug Fixes
  - TLS information delivered in Proxy protocol header is now
    attached to connection metrics as if it was provided by a
    non-proxying client.
  - max_message_size had a one-off error in the validator.
  - mirroring_sync_batch_size was incorrectly validated as if
    it represented batch size in bytes.
  + Stream Plugin
  * Bug Fixes
  - Offset parameters were not stored correctly in some cases.
  - Partitions list order is now stable.
  - When stream clients close connections abruptly, publisher
    and consumer metrics get cleaned up correctly.
  + Management Plugin
  * Enhancements
  - Stream publishers are now listed on the individual stream
    page.
  - Counters have been added to the tiles of several sections
    on detail pages.
  + Dependency Upgrades
  * Osiris was upgraded to 1.2.0
  * Ranch was upgraded to 2.1.0
- Removes socat dependency from specs.
  (gh#rabbitmq/rabbitmq-packaging#8)
- Fix rpmlint errors:
  * E: script-without-shebang for autocomplete scripts
  * E: dir-or-file-in-run /run/rabbitmq
* Tue Sep  7 2021 qydwhotmail@gmail.com
- Update to 3.9.5:
  + Core Server
  * Bug Fixes
  - Virtual host metadata (description, tags) was not imported
    from definitions.
  - Reduced unnecessary debug logging from streams.
  + AWS Peer Discovery Plugin
  * Enhancements
  - AWS API calls are now retried multiple times.
  + Management Plugin
  * Enhancements
  - PUT /api/vhosts/{name} now can update metadata (tags and
    descriptions) for existing virtual hosts.
* Wed Aug 25 2021 qydwhotmail@gmail.com
- Add install-bin and install-man to make target, and install into
  /usr/lib instead of /usr/lib64 on 64-bit platforms (boo#1189784).
- Add deps/rabbit/docs/set_rabbitmq_policy.sh.example to %%doc.
* Mon Aug 23 2021 qydwhotmail@gmail.com
- Separate autocomplete files into individual packages.
* Sun Aug 22 2021 qydwhotmail@gmail.com
- Update to 3.9.4:
  * Bug fixes, see https://www.rabbitmq.com/changelog.html
- Major changes from 3.9.0:
  * Streams: a new messaging abstraction complementary to queues
  * Support for Erlang 24
  * Kubernetes Cluster Operator and Messaging Topology Operator
  * Minimum required Erlang version is now 23.2
- Fix spec file to align with gh#rabbitmq/rabbitmq-packaging/RPMS/Fedora/rabbitmq-server.spec.
- Update rabbitmq-server.service and rabbitmq-server.logrotate.
- Remove unused sources:
  + Already in source:
  * advanced.config.example
  * rabbitmq-script-wrapper
  * rabbitmq.conf.example
  * rabbitmq.config.example
  + Deprecated:
  * rabbitmq-server.init
  * rabbitmq-server.sysconfig
* Thu Jul 15 2021 danilo.spinella@suse.com
- Use /run instead of deprecated /var/run in tmpfiles.conf
  (bsc#1185075)
* Tue May 11 2021 rpm@fthiessen.de
- Update to RabbitMQ 3.8.16
  * This is the first release to drop support for Erlang 22.3 and
  introduce support for the upcoming Erlang 24 release
  * AWS Peer Discovery Plugin was unintentionally excluded from the
  distribution in 3.8.15 and has now been added back.
  * Management Plugin: Messaging polling HTTP API endpoint leaked
  temporary connections it used in case of a polling timeout.
* Fri May  7 2021 rpm@fthiessen.de
- Update to RabbitMQ 3.8.15
  * Fixed quorum queues did not take snapshots as frequently as they
    are expected to with some configurations.
  * Fixed quorum queue name was unintentionally limited: the length
    of virtual host and actual queue name was limited to 254 characters
  * Fixed deleting a quorum queue would leave some of its internal
    metrics data around.
  * Client destination address is now obtained w.r.t. the Proxy
    protocol settings.
  * Full changes:
    https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.15
- Update to RabbitMQ 3.8.14
  * Fixed direct reply-to failed witn an exception on Erlang 22.3
- Update to RabbitMQ 3.8.13
  * Fixed nodes that had an unusually long name could overflow
    message property lengths with the direct reply-to identifier
    they generated.
- Update to RabbitMQ 3.8.12
  * Maintenance mode no longer transfers leaders of classic mirrored
    queue.
  * Exclusive queues that happen to be matched by classic queue
    mirroring policies will no longer be considered for rebalancing
    operations since they are not actually mirrored
  * Default replica count for quorum queues was using an incorrect
    configuration key name. The default value is now 3, so in a
    cluster of five or seven nodes, only three will host replicas
    for newly declared quorum queues.
  * Default runtime busy waiting settings were changed to none by
    default, which reduces CPU footprint on nodes that are mostly idle.
  * Definition import now imports runtime parameters after exchanges,
    queues, and bindings to reduce the likelihood of starting dynamic
    Shovels from racing with topology imports.
  * Fixed memory monitor could run into an exception if queried very
    early on node boot before it was fully initialized.
* Thu Feb  4 2021 jengelh@inai.de
- Remove recipe parts for SUSE 11.x, since that does not build.
* Mon Feb  1 2021 psimons@suse.com
- Update to RabbitMQ 3.8.11
  * Quorum queues that had active consumers during a rolling
    cluster upgrade could run into an exception and restart loop.
  * Nodes that had reverse_dns_lookup set to true could not accept
    client connections.
- Update to RabbitMQ 3.8.10
  * This release deprecates boot time definition import build into
    the management plugin.
  * Repeated polling of a quorum queue with basic.get that yielded
    an empty response could result in an unbounded growth of log
    segment files on on disk.
  * RabbitMQ core plugin activation was revisited to be closer to
    that of 3.7.x. This does not any related improvements w.r.t.
    definition import, e.g. those introudced in RabbitMQ 3.8.6.
  * Syslog dependency was not started correctly. This meant no log
    messages were sent to Syslog.
  * rabbitmq-diagnostics check_if_node_is_quorum_critical returned
    a false positive for a node marked for maintenance.
  * Queues could update their internal bookkeeping state
    incorrectly in some cases, leading to a file_handle_cache
    operation exception.
  * Quorum queues now can use the reject-publish max length
    overflow strategy.
  * Quorum queues now support consumer priority.
  * Per-user connection and queue limits. This is similar to
    per-vhost limits but, as the name suggests, these limits are
    associated for a given user.
  * TLSv1.3 is no longer considered experimental (on Erlang 23) and
    excluded from TLS listener configuration.
  * When a node is put under maintenance, it will now stop all
    local quorum queue replicas after completing leadership
    transfer. This means that no quorum queue replicas on the node
    will be considered for leader elections.
  * Nodes now keep track of failed client authentication attempts
    and expose it as a metric via both the Prometheus endpoint and
    the HTTP API at GET /api/auth/attempts/{node}.
  * bypass_pem_cache is a new configuration key that makes it
    possible to disable the cache of PEM files used by the Erlang
    TLS implementation. This rotated certificates quicker to detect
    for nodes but can also increase latency for inbound TLS
    connections, e.g. under high connection churn scenarios.
  * Definition import now safely handles some missing queue object
    arguments.
  * rabbitmq.conf schema now allows for peer certificate chain
    verification depth to be set to zero. When this value is used,
    peer certificate must be signed by a trusted CA certificate
    directly in order for the verification to pass.
  * RABBITMQ_IO_THREAD_POOL_SIZE will no longer be respected by
    RabbitMQ nodes. It is no longer relevant with supported Erlang
    versions and will simplify rabbitmq-diagnostics
    runtime_thread_stats output.
  * The +K runtime parameter is no longer used by RabbitMQ nodes as
    it has no effect with supported Erlang versions.
* Mon Nov 23 2020 fbui@suse.com
- %%insserv_prereq is only requires when !have_systemd
* Tue Oct 20 2020 g.santomaggio@gmail.com
- Update to RabbitMQ 3.8.9
- RabbitMQ 3.8.9 is a maintenance release.
  It focuses on bug fixes and usability improvements.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.9
- This release no longer supports Erlang 21.3.
- This release is compatible with Erlang 23
- Update to RabbitMQ 3.8.8
- RabbitMQ 3.8.8 is a maintenance release.
  It focuses on bug fixes and usability improvements.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.8
- This is the last RabbitMQ release to support Erlang 21.3.
- This release is compatible with Erlang 23
* Tue Oct  6 2020 dheidler@suse.de
- Add requirement for rabbitmq-server-plugins (boo#1174068)
* Wed Aug 19 2020 gsantomaggio@suse.de
- Update to 3.8.7
- RabbitMQ 3.8.7 is a maintenance release that patches a **security** vulnerability.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.7
- This release requires Erlang/OTP 21.3 or later.
  22.3 or 23.0 releases are recommended.
- Update to 3.8.6
- RabbitMQ 3.8.6 is a maintenance release.
  It focuses on bug fixes and usability improvements.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.6
- This release requires Erlang/OTP 21.3 or later.
  22.3 or 23.0 releases are recommended.
- RabbitMQ Adopts the Mozilla Public License 2.0
  Starting with this release, core RabbitMQ server and all tier 1 plugins [1]
  are relicensed[2] under the Mozilla Public License 2.0[3]
  (previously used license: the Mozilla Public License 1.1).
  The permissiveness of the MPL 2.0 is largely the same as of the MPL 1.1.
  See the MPL 2.0 FAQ[4] and MPL 2.0 Revision and Changes FAQ[5] to learn more.
  1- https://www.rabbitmq.com/plugins.html#plugin-tiers
  2- https://github.com/rabbitmq/rabbitmq-server/issues/2372
  3- https://www.mozilla.org/en-US/MPL/2.0/
  4- https://www.mozilla.org/en-US/MPL/2.0/FAQ/
  5- https://www.mozilla.org/en-US/MPL/2.0/Revision-FAQ/
* Thu Jul  9 2020 gsantomaggio@suse.de
- Update to 3.8.5
- RabbitMQ 3.8.5 is a maintenance release.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.5
- RabbitMQ 3.8.5 is a maintenance release.
- This release requires Erlang/OTP 21.3 or later.
  22.3 or 23.0 series is recommended.
- RabbitMQ 3.8.5 is an RabbitMQ 3.8.0 update
- Update to 3.8.4
- RabbitMQ 3.8.4 is a maintenance release.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.4
- RabbitMQ 3.8.4 is a maintenance release.
- This release requires Erlang/OTP 21.3 or later.
  22.3 or 23.0 series is recommended.
- This is the first release to officially support Erlang 23. Compared to 3.8.3, which
  generally works as expected on Erlang 23, Prometheus monitoring plugin had to
  be adapted to support a memory allocator metric format that has changed compared to
  earlier Erlang releases.
  There is one remaining known Erlang 23 incompatibility: rabbitmq-diagnostics observer will fail on Erlang 23.
  This will be addressed in a future release.
  The root cause is the same memory allocator metric change.
  Provisioning Latest Erlang Releases explains
  what package repositories and tools can be used to provision latest patch versions of Erlang 22.3.x
- RabbitMQ 3.8.4 is an RabbitMQ 3.8.0 update
* Fri Apr 24 2020 dmueller@suse.com
- use python 3.x for building, allows dropping python 2.x
* Thu Mar 12 2020 gsantomaggio@suse.de
- Update to 3.8.3
- RabbitMQ 3.8.3 is a maintenance release.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.3
- RabbitMQ 3.8.3 is a maintenance release.
- This release requires Erlang/OTP 21.3 or later.
  22.x series is recommended.
- RabbitMQ 3.8.3 is an RabbitMQ 3.8.0 update
* Mon Feb 24 2020 gsantomaggio@suse.de
- jsc#SLE-10913
* Mon Feb  3 2020 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Jan 13 2020 g.santomaggio@suse.com
- Update to 3.8.2
- RabbitMQ 3.8.2 is a maintenance release.
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.2
- RabbitMQ 3.8.2 is a maintenance release.
- This release requires Erlang/OTP 21.3 or later.
  22.x series is recommended.
- RabbitMQ 3.8.2 is an RabbitMQ 3.8.0 update
- RabbitMQ 3.8.0 is a feature release. It contains several major improvements
  in areas of data safety, replication, observability, and ease of upgrades.
  Some highlight features are:
  * Quorum Queues
  * Built-in Prometheus support with a set of Grafana dashboards to complement it
  * Feature Flags
  * Single Active Consumer
  * New authentication and authorisation backend that uses OAuth 2.0 (JWT)
    tokens and scopes
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.8.0
- Read the upgrading guide before update: https://www.rabbitmq.com/upgrade.html
* Fri Dec  6 2019 gsantomaggio@suse.de
- Update to RabbitMQ version 3.7.23
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.23
- RabbitMQ 3.7.23 is a maintenance release that focuses on bug fixes.
- RabbitMQ 3.7.x series is supported through March 2020.
- Per the new Erlang version support policy in effect starting with January 2019,
  this release no longer supports Erlang/OTP 20.3.
* Wed Nov 27 2019 gsantomaggio@suse.de
- Update to RabbitMQ version 3.7.22
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.22
- RabbitMQ 3.7.22 is a maintenance release that focuses on bug fixes.
- RabbitMQ 3.7.x series is supported through March 2020.
- Per the new Erlang version support policy in effect starting with January 2019,
  this release no longer supports Erlang/OTP 20.3.
* Mon Nov  4 2019 gsantomaggio@gmail.com
- Update to RabbitMQ version 3.7.21
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.21
- RabbitMQ 3.7.21 is a maintenance release that focuses on bug fixes.
- RabbitMQ 3.7.x series is supported through March 2020.
* Tue Oct 29 2019 gsantomaggio@suse.com
- Update to RabbitMQ version 3.7.20
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.20
- RabbitMQ 3.7.20 is a maintenance release that focuses on bug fixes.
- RabbitMQ 3.7.x series is supported through March 2020.
* Mon Oct 14 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.19
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.19
- RabbitMQ 3.7.19 is a maintenance release that focuses on bug fixes.
- RabbitMQ 3.7.x series is supported through March 2020.
* Tue Sep 17 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.18
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.18
- RabbitMQ 3.7.18 is a maintenance release. It focuses on bug fixes and internal
  API changes that refine the common plugin API with the upcoming 3.8.0 version.
* Mon Aug 19 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.17
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.17
- RabbitMQ 3.7.17 is a maintenance release. It focuses on bug fixes and upgrades
  a JavaScript dependency in the management UI to patch three CVEs in that library.
* Mon Jul 15 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.16
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.16
- RabbitMQ 3.7.16 is a maintenance release.
  It focuses on bug fixes and minor usability improvements. Erlang/OTP Compatibility Notes
  Per the new Erlang version support policy in effect starting with January 2019,
  this release no longer supports Erlang/OTP 19.3.
  Make sure a supported Erlang version is used before upgrading.
* Tue May 21 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.15
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.15
- RabbitMQ 3.7.15 is a maintenance release. It focuses on bug fixes and
  minor usability improvements. This release requires Erlang/OTP 20.3 or later.
  It is also the first release to support Erlang 22.
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Fri Mar 29 2019 g.santomaggio@gmail.com
- Update to RabbitMQ version 3.7.14
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.14
- RabbitMQ 3.7.14 is a maintenance release. It focuses on bug fixes and
  minor usability improvements. This release requires Erlang/OTP 20.3 or later.
* Sun Mar 10 2019 gsantomaggio@suse.com
- Update to RabbitMQ version 3.7.13
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.13
- RabbitMQ 3.7.13 is a maintenance release. It focuses on bug fixes and
  minor usability improvements. This release requires Erlang/OTP 20.3 or later.
* Fri Feb 15 2019 gsantomaggio@suse.com
- Update to RabbitMQ version 3.7.12
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.12
- RabbitMQ 3.7.12 is a maintenance release. It focuses on bug fixes and
  minor usability improvements. This is the first release to require Erlang/OTP 20.3+.
- inet_dist_listen_min and inet_dist_listen_max were removed from new style configuration.
  They wouldn't have any effect due to how configuration translation is performed.
  Use advanced.config or the RABBITMQ_DIST_PORT env variable to configure inet_dist_listen_*
* Fri Feb  1 2019 gsantomaggio@suse.com
- Update to RabbitMQ version 3.7.11
- Full release notes: https://github.com/rabbitmq/rabbitmq-server/releases/tag/v3.7.11
- RabbitMQ 3.7.11 is a maintenance release. It focuses on bug fixes and
  minor usability improvements. This is the first release to require Erlang/OTP 20.3+.
* Mon Jan 21 2019 gsantomaggio@suse.com
- Update to RabbitMQ version 3.7.10
- Requires erlang to 20.3, mandatory for RabbitMQ 3.7.10
  see: https://www.rabbitmq.com/which-erlang.html
* Tue Jan  8 2019 jengelh@inai.de
- Avoid name repetition in summary. Trim filler wording from
  descriptions.
* Wed Jan  2 2019 gsantomaggio@suse.com
- add the 3.7.x command line tools
* Mon Dec 17 2018 dmueller@suse.com
- switch to 3.7.x style rabbitmq-server.conf
- Remove sd_notify dependency and replace with socat as
  followup to upstream change in
  https://github.com/rabbitmq/rabbitmq-server/pull/666
* Sat Dec 15 2018 dmueller@suse.com
- listen to localhost only by default to comply to the epmd.socket
  which also only listens to localhost (bsc#1087270)
* Tue Dec  4 2018 matwey.kornilov@gmail.com
- Fix Source0 URL
* Fri Nov 16 2018 matwey.kornilov@gmail.com
- BuildRequire elixir
- Constrain required erlang versions:
  https://www.rabbitmq.com/which-erlang.html (boo#1115169)
- Drop sysexists-in-ocf.patch: upstreamed
- Update to 3.7.9 (fate#322425, bsc#1115466)
- Changes for 3.7.9:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.8:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.7:
  * Erlang 21 compatibility
  * Bug fixes
  * Usability improvements
- Changes for 3.7.6:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.5:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.4:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.3:
  * Bug fixes
  * Usability improvements
- Changes for 3.7.2:
  * Bug fix in the HTTP auth backend
- Changes for 3.7.1:
  * Bug fixes
- Changes for 3.7.0:
  * Minimum required Erlang version is now 19.3
  * Automation-friendly cluster formation
  * Distributed management plugin, including minor breaking HTTP API
  changes.
  * Simpler, ini-style configuration format
  * Per-vhost limits
  * Operator policies
  * Topic-based authorisation
  * Cross-protocol Shovel (currently supports AMQP 0.9.1 and AMQP 1.0)
  * Command-line tools are extensible via plugins
  * Message store multi-tenancy
  * Proxy protocol support
  * Web STOMP no longer supports WebSocket emulation
  * Java and .NET client releases no longer track RabbitMQ server
  releases
  * .NET client now supports .NET Core.
  * Management plugin extensions now must target Cowboy 2.0
  * Java client for RabbitMQ HTTP API
* Tue Sep 11 2018 dmueller@suse.com
- update config.template to use channel_max to 0 (old default,
  mitigate breakage in 3.6.16 change)
* Mon Sep 10 2018 dmueller@suse.com
- update to 3.6.16 (bsc#1109991):
  Bug fixes:
  + Queue master locator min-masters incorrectly calculated the number of masters.
  + Maximum supported number of queue priorities (255) is now enforced
  Enhancements:
  + queue.delete operations will now force delete queues that don't have a promotable master
  + Lock contention in internal database is now much lower when a node with a lot of exclusive queues
  shuts down or is otherwise considered to be unavailable by peers
  + Default max number of channels allowed on a connection (a.k.a. channel_max) has been lowered from 65535 to 2047.
  The new default is much safer and will reduce the effect application channel leaks have on node resource consumption. This is a potentially breaking change.
* Tue Jun 12 2018 jtomasiak@suse.com
- Add sysexits-in-ocf.patch to handle new rabbitmqctl exit codes
  (bsc#1093046)
* Mon May 28 2018 bwiedemann@suse.com
- Add TasksMax=8192 to start on large machines (bsc#1094896)
* Mon Jan 22 2018 vuntz@suse.com
- Update to 3.6.15:
  + Bug fixes:
  - Avoid infinite loop when dropping entries in the GM.
  - Various changes to the OCF scripts.
  + Enhancements:
  - Internal authN backend will now prohibit logins with a blank
    passwords.
  + Bug fixes in plugins.
- Remove ocf-pull-request-63.patch, ocf-pull-request-64.patch,
  ocf-pull-request-66.patch: merged upstream.
* Thu Jan 18 2018 vuntz@suse.com
- Add TimeoutStartSec=300 to rabbitmq-server.service as enabling
  HiPE can make the startup take much longer (documentation says
  "a few minutes").
* Wed Dec 13 2017 vuntz@suse.com
- Add ocf-pull-request-63.patch and ocf-pull-request-64.patch:
  fixes to avoid moving master unnecessarily, and to make start
  notification handler more reliable.
- Add ocf-pull-request-66.patch: do not consider transient local
  failures as failures of remote nodes.
* Tue Dec 12 2017 ilausuch@suse.com
- modified logrotate to use rabbitmqctl to force the creation of the
  log file after logrotation
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Nov 16 2017 dmueller@suse.com
- update to 3.6.14:
  * package/systemd bug fixes
  * Usability improvements
  * Bug fixes
* Wed Aug 23 2017 tbechtold@suse.com
- update to 3.6.11:
  * packaging: package-rpm-suse is an alias for package-rpm-opensuse
  * Makefile: Move plugins list to `plugins.mk`
  * Include rabbitmq_web_mqtt into the distribution
  * Log rabbitmqctl's output on failure
  * Makefile: Set default `broker_version_requirements`
  * packaging/windows: Allow to override `PRODUCTVERSION`
  * debian/control: Revert the use of ${misc:Depends}
  * packaging: Add scripts for format RabbitMQ version to match package constarints
  * Commit Debian and RPM changelogs
  * debian/control: Use ${misc:Depends} instead of hard-coding dependencies
  * Fix HA OCF script
  * Makefile: Store the plugins list in the source archive
  * plugins.mk: The list is overriden by the server-release Concourse pipeline
  * Makefile: Use PROJECT_DESCRIPTION in git-revisions.txt
  * packaging/RPMS: Simplify the Makefile wrapping dpkg-buildpackage(1)
  * Makefile: Sync exclusion list with rabbitmq-erlang-client
  * OCF RA: accept 1 as valid exit code from "rabbitmqctl status"
  * Ignore .envrc files
  * upgrade/Makefile: Remove trailing space
  * standalone/src/rabbit_release.erl: Copy `escript` directory to the archive
  * packaging/standalone: Remove the source `rabbit.rel` file
  * Commit .deb and .rpm change logs
  * OCF RA: Don't hardcode primitive name in rabbitmq-server-ha.ocf
  * Makefile: Use $(PROJECT_VERSION) instead of $(VERSION)
  * debian/control: Add version restriction on erlang-dev and esl-erlang
  * Commit 3.6.9 package change logs
  * packaging/standalone: Fix path to the source `rabbit.rel` file
  * Configure shortcuts to run as admin.
  * Debian package: No need to pass $(VERSION) around in debian/rules
  * Makefile: Use a recursively expanded var for `RABBITMQ_VERSION`
  * Add Travis tests for Pacemaker OCF RA cluster
  * Makefile: Load rabbitmq-dist.mk before rabbitmq-run.mk
  * packaging/debs/Debian/Makefile: Display Erlang version *after* installing it
  * packaging/debs/Debian/scripts/udpate-changelog.sh: Show syntax
  * packaging/standalone: Do not use NUL-separated filenames in manifest
  * packaging/standalone: Copy `start_clean.boot` to bin driectory
  * packaging: rpms: Add systemd support for openSUSE
  * packaging/debs/Debian/Makefile: Install build dependencies
  * packaging/RPMS: Fix SAVE_CHANGELOG handling
  * Makefile: Call $(MAKE), not plain `make`
  * packaging/*/rabbitmq-server.service: Wait for RabbitMQ to stop in ExecStop
  * packaging/debs: Use make conditionals instead of Bourne shell ones
  * packaging/debs: Derive GNUPGHOME from KEYSDIR
  * Add chmod g+s to /etc/rabbitmq
  * packaging/standalone: Remove temporary `expand` directory
  * packaging/windows: Try to compute a valid default `PRODUCTVERSION`
  * Enlist OCF_RESKEY_limit_nofile_default on comment
  * Re-do #21
  * Makefile: Exclude `/rabbit{,mq_cli}/escript/` from the source archive
  * debian/control: Try with erlang-nox 1:16.b.3-3
  * packaging/standalone: Use an intermediate file to list files to archive
  * Makefile: Use an intermediate file to list files to put in the source archive
  * Makefile: Use echo instead of printf
  * debian/control: Depend on erlang-src
  * Change to 2750
  * Trigger a Travis build
  * packaging: Log the version of Erlang used to compile packages
  * Update erlang.mk
  * packaging/debs/apt-repository/distributions: Add `arm64` architecture
  * Require root or rabbitmq user for rabbitmq-plugins.
  * Makefile: Remove more unneeded files from the source archive
  * Update rabbitmq-components.mk
  * Placeholder, remove later.
  * packaging/windows: Bump copyright of the installer to 2017
  * Manually backport #20, #21, #24, #25 by @vuntz and @aplanas to stable
  * packaging/debs: Simplify the Makefile wrapping dpkg-buildpackage(1)
  * plugins.mk: Sort list alphabetically
  * Add write permissions to erl
  * OCF RA: Add new limit_nofile parameter to rabbitmq-server OCF RA
  * packaging/debs/Debian/Makefile: Use cp(1) instead of rsync(1)
  * scripts/rabbitmq-script-wrapper: Run rabbitmq-plugin as root only
  * Remove.
  * Add `standalone-linux-x86_64` and `standalone-freebsd-x86_64` package targets
  * Makefile: Remove all targets entering the `upgrade` subdir
  * OCF RA: Use rabbitmqctl_action wrapper for stop action
  * README.md: Document how to build the source archive and packages
  * README.md: Document how Windows' PRODUCTVERSION is computed by default
  * Add chmod g+s to rpm spec
- Drop pull-request-20.patch . Applied upstream.
- Drop pull-request-21.patch . Applied upstream.
- Drop pull-request-24.patch . Applied upstream.
- Drop pull-request-25.patch . Applied upstream.
* Wed Apr  5 2017 vuntz@suse.com
- Stop shipping rabbitmq-server OCF resource agent as source file
  while it's included in the upstream tarball. Add patches for code
  that was specific to our variant; they now got upstreamed, but
  are not in this version of rabbitmq yet: pull-request-20.patch
  and pull-request-21.patch.
- Also package the rabbitmq-server-ha OCF resource agent as it
  seems to be more appropriate for clustering. Add upstream fixes
  for making it more solid: pull-request-24.patch and
  pull-request-25.patch.
- Ship an example of /etc/rabbitmq/rabbitmq-env.conf, as this is
  useful indication. It only contains commented examples, based on
  what the Debian package is doing.
* Wed Feb 15 2017 mrueckert@suse.de
- Cleanup file list and prepare merging the plugins package into
  the main package:
  - No longer create parts of the filelist in %%install
  - Only exclude the plugins starting with rabbitmq_* and not all
    files in the plugin dir. Some of the files are basic libraries
    needed to even launch rabbitmq. (boo#1025442)
- in the tmpfiles.d file: make the directory group owned
- own the run dir in the non systemd case
* Mon Feb 13 2017 mrueckert@suse.de
- add buildrequires for xz to fix build on sle11
* Thu Feb  9 2017 mrueckert@suse.de
- drop no-remove-common.patch and no-nmap.patch:
  no longer needed
* Thu Feb  9 2017 mrueckert@suse.de
- add back default config from the 3.5.8 package as 3.6.6 doesn't
  ship one anymore
- rabbitmq-script-wrapper now directly talks to the scripts in
  _rabbit_erllibdir instead of having another indirection.
- moved tmpfiles.d support into the main systemd install block
- extracted make cmdline options into a variable
* Mon Feb  6 2017 mrueckert@suse.de
- update to 3.6.6
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_6
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_5
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_4
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_3
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_2
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_1
  https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_6_0
* Mon Feb  6 2017 mrueckert@suse.de
- fix source url
* Mon Feb  6 2017 mrueckert@suse.de
- IMPORTANT CHANGE
  Require the epmd service instead of running our own version as
  rabbitmq user.
  This requires that you configure epmd to listen on more
  interfaces than just 127.0.0.1.
  For non systemd based distributions you can set EPMD_ADDRESSES in
  /etc/sysconfing/erlang.
  For systemd based distributions please follow
  /usr/share/doc/packages/erlang/README.SUSE
  IMPORTANT CHANGE
  This change is also documented in
  /usr/share/doc/packages/rabbitmq-server/README.SUSE
* Tue Jan 17 2017 chris@intrbiz.com
- Update to 3.5.8
  Fixes logging issues on erlang 17+
  Fixes MQTT password authentication error (CVE-2016-9877) (boo#1017642)
* Thu Apr 14 2016 aplanas@suse.com
  Fix bsc#973999
- rabbitmq-server.service: increase NOFILE limit per documentation
- rabbitqm-server.ocf: add OCF_RESKEY_limit_nofile parameter
  default as 65535
* Mon Sep 28 2015 dmueller@suse.com
- rabbitmqctl: clear CMDLINE before appending
* Thu Sep 24 2015 dmueller@suse.com
- update to 3.5.4:
  Runtime I/O thread pool size is now 64 instead of 30 by default.
  This reduces time spent waiting for file I/O operations to complete
  on machines with 8 or more cores.
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_4
* Wed Jun 24 2015 dmueller@suse.com
- rabbitmq-server.service: switch to type=Notify in order to
  avoid cookie creation race
* Tue Jun 23 2015 tbechtold@suse.com
- update to 3.5.3:
  3.5.2 and 3.5.3 are bugfix releases. See:
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_2
  * https://github.com/rabbitmq/rabbitmq-server/releases/tag/rabbitmq_v3_5_3
* Sun Apr 12 2015 mrueckert@suse.de
- update to 3.5.1
  This release adds support for priority queues which were available
  as a plugin before. Performance is improved; in particular messages
  smaller than configurable size are embedded in the queue index to
  reduce I/O and memory consumption. Stability of clustering and
  autoheal partition handling is improved as well. A new
  pause_if_all_down partition handling mode is added. The management
  web UI now shows many more I/O statistics.
  This release also corrects a number of defects in the broker and
  plugins, as well as introducing many smaller new features and
  improvements.
  * see https://www.rabbitmq.com/release-notes/README-3.5.1.txt
  * see https://www.rabbitmq.com/release-notes/README-3.5.0.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.4.txt
- instead of patching the ocf provider after copying: patch it
  right away and drop the ocf-fixes.patch.
- refresh no-nmap.patch to apply cleanly again
- create rcrabbitmq-server for the systemd case
* Wed Jan 21 2015 dmueller@suse.com
- update to 3.4.3:
  * prevent XSS attack in table key names (since 2.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in policy names (since 3.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in client details in the connections list
    (CVE-2015-0862)
  * prevent XSS attack in user names in the vhosts list or the vhost names
    in the user list (since 2.4.0)
    (CVE-2015-0862)
  * prevent XSS attack in the cluster name (since 3.3.0)
    (CVE-2015-0862)
  * prevent /api/* from returning text/html error messages which could
    act as an XSS vector (since 2.1.0)
  * fix response-splitting vulnerability in /api/downloads (since 2.1.0)
  * do not trust X-Forwarded-For header when enforcing 'loopback_users'
    (CVE-2014-9494)
  * disable SSLv3 by default to prevent the POODLE attack
  * see https://www.rabbitmq.com/release-notes/README-3.4.3.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.2.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.1.txt
  * see https://www.rabbitmq.com/release-notes/README-3.4.0.txt
* Mon Nov 24 2014 dmueller@suse.com
- ignore stop errors in %%preun
* Sun Sep 14 2014 tbechtold@suse.com
- update to 3.3.5:
  * Bug fixes, see
  - https://www.rabbitmq.com/release-notes/README-3.3.2.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.3.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.4.txt
  - https://www.rabbitmq.com/release-notes/README-3.3.5.txt
* Sun Jul 20 2014 p.drouand@gmail.com
- The package doesn't provide any sysvinit script or sysconfig file;
  remove dependencies to fillup or insserv if the package build with
  systemd support
* Mon May  5 2014 dmueller@suse.com
- update to 3.3.1:
  * Bug fixes
  * Security fixes to MQTT and shovel
  * see http://www.rabbitmq.com/release-notes/README-3.3.1.txt
* Wed Apr 30 2014 dmueller@suse.com
- do not install init script on systemd distros
* Thu Apr 10 2014 matwey.kornilov@gmail.com
- require epmd.socket in .service in order not to start earlier
  than epmd.socket
* Fri Apr  4 2014 dmueller@suse.com
- update to 3.3.0:
  * long list of security, bugfixes and enhancements
  * see http://www.rabbitmq.com/release-notes/README-3.3.0.txt
* Wed Apr  2 2014 vuntz@suse.com
- Add ocf-fixes.patch to fix issues in the OCF file:
  - use the wrapper function to call rabbitmqctl for stop, so that
    we interpret correctly the exit code.
  - accept 1 as valid exit code from "rabbitmqctl status", instead
    of totally breaking when we get it.
- We use a patch as the OCF file comes from upstream, so it's
  better to keep the changes isolated.
* Thu Mar 27 2014 dmueller@suse.com
- update to 3.2.4:
  * Several bug fixes, no detailed changelog available
- remove fix-syntax-error-in-example-conf.patch: merged upstream
* Fri Jan 24 2014 dmueller@suse.com
- update to 3.2.3:
  * This release fixes a number of bugs in the broker and federation plugin
  * Improvements to the LDAP and shovel plugins are also included
* Thu Jan 23 2014 dmueller@suse.com
- install a config file by default
  add fix-syntax-error-in-example-conf.patch
* Tue Jan 21 2014 dmueller@suse.com
- update to 3.2.2:
  * federated queues and features enhanced policies for aspects of the broker
  * This release fixes a number of bugs in the broker and plugins
* Tue Jan  7 2014 matwey.kornilov@gmail.com
- add Provides: erlang-gen_server2 to erlang-rabbitmq_client
  (many people want gen_server2, which is a part of rabbitmq)
* Fri Sep 20 2013 dmueller@suse.com
- fix syntax error in wrapper script
* Fri Sep 13 2013 dmueller@suse.com
- update to 3.1.5:
  * various security fixes and bugfixes
  * see http://www.rabbitmq.com/release-notes/README-3.1.5.txt
  * see http://www.rabbitmq.com/release-notes/README-3.1.4.txt
* Wed Jul  3 2013 dmueller@suse.com
- update to 3.1.3:
  * Eager synchronisation of mirror queue slaves
  * Automatic cluster partition healing
  * Charts in the management plugin
  * Queue length limits
  * Bug fixes
  * Fixes a security bug in federation
* Wed Apr 24 2013 tpaszkowski@novell.com
- fix rabbitmq-server startup on systemd enabled systems (create
  /var/run/rabbitmq-server directory using systemd-tmpfiles mechanism)
* Wed Apr  3 2013 dmueller@suse.com
- Change init script to properly daemonize (patch by jdsn) (bnc#807540)
* Sun Mar 17 2013 matwey.kornilov@gmail.com
- Added systemd .service file
* Wed Mar 13 2013 berendt@b1-systems.de
- updated to version 3.0.4
  * 3.0.4: This release fixes a bug in the federation plugin
    where upstream credentials were leaked in the
    x-received-from header. This bug had been in the federation
    plugin since RabbitMQ 3.0.0. There are no other changes
    from RabbitMQ 3.0.3.
  * 3.0.3: This release fixes a small number of bugs in 3.0.2
    and earlier versions.
  * 3.0.2: This release fixes a number of bugs in 3.0.1 and
    earlier versions.
  * 3.0.1: This release fixes a number of bugs in 3.0.0 and
    earlier versions.
  * 3.0.0: This release introduces dynamic, policy-based control
    of mirroring and federation, improves the user friendliness
    of clustering, adds support for per-message TTL, introduces
    plugins for web-STOMP and MQTT, and adds many smaller new
    features and bug fixes.
- rebased no-remove-common.patch
* Fri Dec 14 2012 rhafer@suse.com
- sysconfig file cleanup
  * remove unused Variables
  * removed variables which can also be set in rabbitmq-env.conf
    to avoid sysconfig settings overriding settings from the env
    file (bnc#771151)
- Use rc.status functions in init script for prettier startup
- Remove "set -e" from init script (bnc#768175)
- Include OCF RA for use with Pacemaker
- Updated script-wrapper to the latest upstream code
* Fri Dec 14 2012 saschpe@suse.de
- Don't use download_files service, or at least only in mode="localonly"
  or mode="disabled". But why using it at all, it makes no sense.
* Mon Dec 10 2012 rhafer@suse.com
- Update to 2.8.7 changes since:
  * 2.8.6: This release fixes a number of bugs in the broker,
    Erlang client and STOMP and management plugins.
  * 2.8.5: This release fixes a number of bugs, including one
    introduced in 2.8.5 that could cause an error during shutdown
    of mirrored queues.
  * 2.8.4: This is primarily a bugfix release, with several
    improvements to HA queues.
* Fri Aug 17 2012 mbarringer@suse.com
- Fixing logrotate errors (bnc#775867)
* Mon Jul 16 2012 matwey.kornilov@gmail.com
- Updated to 2.8.4
* Wed May  9 2012 matwey.kornilov@gmail.com
- Updated to 2.8.2
* Fri Apr 13 2012 jblunck@opensuse.org
- Require python >= 2.6 for json
- Add _initddir define for SLE11 build
* Tue Feb 14 2012 saschpe@suse.de
- Fixed doubled preamble entries
* Thu Feb  2 2012 bwiedemann@suse.com
- fix /var/run/rabbitmq ownership
* Tue Jan 10 2012 prusnak@opensuse.org
- updated to 2.7.1
- don't use nmap during the build (no-nmap.patch)
- don't use /var/lock/subsys in initscript
- create /var/run/rabbitmq in initscript
- import changes from Fedora package
* Sun Oct  4 2009 dpw@lshift.net
- New upstream release
* Tue Jun 16 2009 matthias@lshift.net
- New upstream release
* Mon May 18 2009 matthias@lshift.net
- Maintenance release for the 1.5.x series
* Sun Apr  5 2009 matthias@lshift.net
- Maintenance release for the 1.5.x series
* Mon Feb 23 2009 tonyg@lshift.net
- Maintenance release for the 1.5.x series
* Sun Feb 22 2009 tonyg@lshift.net
- Maintenance release for the 1.5.x series
* Sun Jan 18 2009 0x6e6562@gmail.com
- Maintenance release for the 1.5.x series
* Tue Dec 16 2008 matthias@lshift.net
- New upstream release
* Wed Jul 23 2008 tonyg@lshift.net
- New upstream release
* Sun Mar  2 2008 adrian@lshift.net
- New upstream release
* Tue Sep 25 2007 simon@lshift.net
- New upstream release
* Tue Aug 28 2007 simon@lshift.net
- New upstream release
* Sun Jul 29 2007 simon@lshift.net
- New upstream release
* Mon Jun 11 2007 hubert@lshift.net
- Building from source tarball, added starting script, stopping
* Sun May 20 2007 hubert@lshift.net
- Initial build of server library of RabbitMQ package
